/**
* Filename: ValueContainer.java (in org.openbandy.io)
* This is part of the OpenBandy project.

* @author Philipp Bolliger (philipp@bolliger.name)
* @version 0.8
* 
* (c) Copyright 2007, ALL RIGHTS RESERVED.
*
* The ValueContainer is a temporary reservoir for one
* serializable object's attributes. 
*/

package org.openbandy.io;

public abstract class ValueContainer {
    
    /* Constants to store boolean values */
    public final static String TRUE = "t";
    public final static String FALSE = "f";


    /* Setter Methods */
    
	/**
	 * @param name - the name of the attribute
	 * @param value - the String value of the attribute
	 */
	public abstract void addString(String name, String value);
	
	/**
	 * @param name -  the name of the attribute
	 * @param value - the byte value of the attribute
	 */
	public void addByte(String name, byte value) {
		addString(name, String.valueOf(value));	
	}
	
	/**
	 * @param name -  the name of the attribute
	 * @param value - the short value of the attribute
	 */
	public void addShort(String name, short value) {
		addString(name, Integer.toString(value));
	}
	
	/**
	 * @param name -  the name of the attribute
	 * @param value - the int value of the attribute
	 */
	public void addInt(String name, int value) {
		addString(name, Integer.toString(value));
	}
	
	/**
	 * @param name -  the name of the attribute
	 * @param value - the long value of the attribute
	 */
	public void addLong(String name, long value) {
		addString(name, Long.toString(value));
	}
	
	/**
	 * @param name -  the name of the attribute
	 * @param value - the float value of the attribute
	 */
	public void addFloat(String name, float value) {
		addString(name, Float.toString(value));
	}
	
	/**
	 * @param name -  the name of the attribute
	 * @param value - the double value of the attribute
	 */
	public void addDouble(String name, double value) {
		addString(name, Double.toString(value));
	}
    
    /**
     * @param name -  the name of the attribute
     * @param value - the boolean value of the attribute
     */
	public void addBoolean(String name, boolean value) {
		if(value){
			addString(name, TRUE);
		}
		else{
			addString(name, FALSE);
		}
	}
	
	/**
	 * @param name -  the name of the attribute
	 * @param value - the char value of the attribute
	 */
	public void addChar(String name, char value) {
		addString(name, String.valueOf(value));	
	}
	
	/**
	 * @param name -  the name of the attribute
	 * @param value - the value of the timestamp defined as
	 *                milliseconds since midnight, January 1,
	 *                1970 UTC
	 */
	public void addTimestamp(String name, long value) {
		addLong(name, value);
	}

	
	/* Getter Methods */
	
	/**
	 * @param name -  the name of the attribute
	 * @return Returns the corresponding String value
	 *         if available, null else
	 */
	public abstract String getString(String name);
	
	/**
	 * @param name -  the name of the attribute
	 * @return Returns the corresponding byte value
	 *         if available, 0 else
	 */
	public byte getByte(String name) {
		String value = getString(name);
		if(value == ""){
			return 0;
		}
		return Byte.parseByte(value);
	}
	
	/**
	 * @param name -  the name of the attribute
	 * @return Returns the corresponding short value
	 *         if available, 0 else
	 */
	public short getShort(String name) {
		String value = getString(name);
		if(value == ""){
			return 0;
		}
		return Short.parseShort(value);
	}
	
	/**
	 * @param name -  the name of the attribute
	 * @return Returns the corresponding int value
	 *         if available, 0 else
	 */
	public int getInt(String name) {
		String value = getString(name);
		if(value == ""){
			return 0;
		}
		return Integer.parseInt(value);
	}
	
	/**
	 * @param name -  the name of the attribute
	 * @return Returns the corresponding long value
	 *         if available, 0L else
	 */
	public long getLong(String name) {
		String value = getString(name);
		if(value == ""){
			return 0;
		}
		return Long.parseLong(value);
	}
	
	/**
	 * @param name -  the name of the attribute
	 * @return Returns the corresponding float value
	 *         if available, 0.0f else
	 */
	public float getFloat(String name) {
		String value = getString(name);
		if(value == ""){
			return 0;
		}
		return Float.parseFloat(value);
	}
	
	/**
	 * @param name -  the name of the attribute
	 * @return Returns the corresponding double value
	 *         if available, 0.0d else
	 */
	public double getDouble(String name) {
		String value = getString(name);
		if(value == ""){
			return 0;
		}
		return Double.parseDouble(value);
	}
    
    /**
     * @param name -  the name of the attribute
     * @return Returns the corresponding boolean value
     *         if available, <code>false</code> else
     */
	public boolean getBoolean(String name) {
		String value = getString(name);
		if(value.equals(TRUE)){
			return true;
		}
		else{
			return false;
		}
	}
	
	/**
	 * @param name -  the name of the attribute
	 * @return Returns the corresponding char value
	 *         if available, '\u0000' else
	 */
	public char getChar(String name) {
		String value = getString(name);
		if(value == ""){
			return 0;
		}
		return value.charAt(0);
	}
	
	/**
	 * @param name -  the name of the attribute
	 * @return Returns the timestamp value defined as
	 *         milliseconds since midnight, January 1,
	 *         1970 UTC if available, 0.0 else
	 */
	public long getTimestamp(String name) {
		return getLong(name);
	}
}
